@@ -28,7 +28,7 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #if !defined (__STDC__) || !__STDC__
