@@ -1,6 +1,11 @@
 /* main.c
 
-Copyright (C) 1999,2000 Tom Gilbert.
+Copyright 1999-2000 Tom Gilbert <tom@linuxbrit.co.uk,
+                                  gilbertt@linuxbrit.co.uk,
+                                  scrot_sucks@linuxbrit.co.uk>
+Copyright 2009      James Cameron <quozl@us.netrek.org>
+Copyright 2010      Ibragimov Rinat <ibragimovrinat@mail.ru>
+Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -48,9 +53,14 @@ main(int argc,
   }
 
 
-  if (opt.select)
+  if (opt.focused)
+    image = scrot_grab_focused();
+  else if (opt.select)
     image = scrot_sel_and_grab_image();
-  else {
+  else if (opt.autoselect)
+    image = gib_imlib_create_image_from_drawable(root, 0, opt.autoselect_x, opt.autoselect_y, opt.autoselect_w, opt.autoselect_h, 1);
+  else
+  {
     scrot_do_delay();
     if (opt.multidisp) {
       image = scrot_grab_shot_multi();
@@ -152,7 +162,7 @@ scrot_grab_shot(void)
 {
   Imlib_Image im;
 
-  XBell(disp, 0);
+  if (! opt.silent) XBell(disp, 0);
   im =
     gib_imlib_create_image_from_drawable(root, 0, 0, 0, scr->width,
                                          scr->height, 1);
@@ -170,6 +180,22 @@ scrot_exec_app(Imlib_Image image, struct tm *tm,
   exit(0);
 }
 
+Imlib_Image
+scrot_grab_focused(void)
+{
+  Imlib_Image im = NULL;
+  int rx = 0, ry = 0, rw = 0, rh = 0;
+  Window target = None;
+  int ignored;
+
+  scrot_do_delay();
+  XGetInputFocus(disp, &target, &ignored);
+  if (!scrot_get_geometry(target, &rx, &ry, &rw, &rh)) return NULL;
+  scrot_nice_clip(&rx, &ry, &rw, &rh);
+  im = gib_imlib_create_image_from_drawable(root, 0, rx, ry, rw, rh, 1);
+  return im;
+}
+
 Imlib_Image
 scrot_sel_and_grab_image(void)
 {
@@ -313,64 +339,83 @@ scrot_sel_and_grab_image(void)
         rh = 0 - rh;
       }
     } else {
-      Window child;
-      XWindowAttributes attr;
-      int stat;
-
       /* else it's a window click */
-      /* get geometry of window and use that */
-      /* get windowmanager frame of window */
-      if (target != root) {
-        unsigned int d, x;
-        int status;
-
-        status = XGetGeometry(disp, target, &root, &x, &x, &d, &d, &d, &d);
-        if (status != 0) {
-          Window rt, *children, parent;
-
-          for (;;) {
-            /* Find window manager frame. */
-            status = XQueryTree(disp, target, &rt, &parent, &children, &d);
-            if (status && (children != None))
-              XFree((char *) children);
-            if (!status || (parent == None) || (parent == rt))
-              break;
-            target = parent;
-          }
-          /* Get client window. */
-          if (!opt.border)
-            target = scrot_get_client_window(disp, target);
-          XRaiseWindow(disp, target);
-        }
-      }
-      stat = XGetWindowAttributes(disp, target, &attr);
-      if ((stat == False) || (attr.map_state != IsViewable))
-        return NULL;
-      rw = attr.width;
-      rh = attr.height;
-      XTranslateCoordinates(disp, target, root, 0, 0, &rx, &ry, &child);
+      if (!scrot_get_geometry(target, &rx, &ry, &rw, &rh)) return NULL;
     }
+    scrot_nice_clip(&rx, &ry, &rw, &rh);
 
-    /* clip rectangle nicely */
-    if (rx < 0) {
-      rw += rx;
-      rx = 0;
-    }
-    if (ry < 0) {
-      rh += ry;
-      ry = 0;
-    }
-    if ((rx + rw) > scr->width)
-      rw = scr->width - rx;
-    if ((ry + rh) > scr->height)
-      rh = scr->height - ry;
-
-    XBell(disp, 0);
+    if (! opt.silent) XBell(disp, 0);
     im = gib_imlib_create_image_from_drawable(root, 0, rx, ry, rw, rh, 1);
   }
   return im;
 }
 
+/* clip rectangle nicely */
+void
+scrot_nice_clip(int *rx, 
+		int *ry, 
+		int *rw, 
+		int *rh)
+{
+  if (*rx < 0) {
+    *rw += *rx;
+    *rx = 0;
+  }
+  if (*ry < 0) {
+    *rh += *ry;
+    *ry = 0;
+  }
+  if ((*rx + *rw) > scr->width)
+    *rw = scr->width - *rx;
+  if ((*ry + *rh) > scr->height)
+    *rh = scr->height - *ry;
+}
+
+/* get geometry of window and use that */
+int
+scrot_get_geometry(Window target,
+		   int *rx, 
+		   int *ry, 
+		   int *rw, 
+		   int *rh)
+{
+  Window child;
+  XWindowAttributes attr;
+  int stat;
+
+  /* get windowmanager frame of window */
+  if (target != root) {
+    unsigned int d, x;
+    int status;
+    
+    status = XGetGeometry(disp, target, &root, &x, &x, &d, &d, &d, &d);
+    if (status != 0) {
+      Window rt, *children, parent;
+      
+      for (;;) {
+	/* Find window manager frame. */
+	status = XQueryTree(disp, target, &rt, &parent, &children, &d);
+	if (status && (children != None))
+	  XFree((char *) children);
+	if (!status || (parent == None) || (parent == rt))
+	  break;
+	target = parent;
+      }
+      /* Get client window. */
+      if (!opt.border)
+	target = scrot_get_client_window(disp, target);
+      XRaiseWindow(disp, target);
+    }
+  }
+  stat = XGetWindowAttributes(disp, target, &attr);
+  if ((stat == False) || (attr.map_state != IsViewable))
+    return 0;
+  *rw = attr.width;
+  *rh = attr.height;
+  XTranslateCoordinates(disp, target, root, 0, 0, rx, ry, &child);
+  return 1;
+}
+
 Window
 scrot_get_window(Display * display,
                  Window window,
