@@ -1,6 +1,13 @@
 /* options.c
 
-Copyright (C) 1999,2000 Tom Gilbert.
+Copyright 1999-2000 Tom Gilbert <tom@linuxbrit.co.uk,
+                                  gilbertt@linuxbrit.co.uk,
+                                  scrot_sucks@linuxbrit.co.uk>
+Copyright 2008      William Vera <billy@billy.com.mx>
+Copyright 2009      George Danchev <danchev@spnet.net>
+Copyright 2009      James Cameron <quozl@us.netrek.org>
+Copyright 2010      Ibragimov Rinat <ibragimovrinat@mail.ru>
+Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -44,21 +51,25 @@ init_parse_options(int argc, char **argv)
 static void
 scrot_parse_option_array(int argc, char **argv)
 {
-   static char stropts[] = "bcd:e:hmq:st:v+:";
+   static char stropts[] = "a:bcd:e:hmq:st:uv+:z";
    static struct option lopts[] = {
       /* actions */
       {"help", 0, 0, 'h'},                  /* okay */
       {"version", 0, 0, 'v'},               /* okay */
       {"count", 0, 0, 'c'},
       {"select", 0, 0, 's'},
+      {"focused", 0, 0, 'u'},
+      {"focussed", 0, 0, 'u'},	/* macquarie dictionary has both spellings */
       {"border", 0, 0, 'b'},
       {"multidisp", 0, 0, 'm'},
+      {"silent", 0, 0, 'z'},
       /* toggles */
       {"thumb", 1, 0, 't'},
       {"delay", 1, 0, 'd'},
       {"quality", 1, 0, 'q'},
       {"exec", 1, 0, 'e'},
       {"debug-level", 1, 0, '+'},
+      {"autoselect", required_argument, 0, 'a'},
       {0, 0, 0, 0}
    };
    int optch = 0, cmdx = 0;
@@ -95,6 +106,9 @@ scrot_parse_option_array(int argc, char **argv)
         case 's':
            opt.select = 1;
            break;
+        case 'u':
+           opt.focused = 1;
+           break;
         case '+':
            opt.debug_level = atoi(optarg);
            break;
@@ -104,6 +118,12 @@ scrot_parse_option_array(int argc, char **argv)
         case 't':
            options_parse_thumbnail(optarg);
            break;
+        case 'z':
+           opt.silent = 1;
+           break;
+        case 'a':
+	  options_parse_autoselect(optarg);
+	   break;
         default:
            break;
       }
@@ -119,6 +139,12 @@ scrot_parse_option_array(int argc, char **argv)
          if (!opt.output_file)
          {
             opt.output_file = argv[optind++];
+
+            if ( strlen(opt.output_file) > 256 ) {
+               printf("output filename too long.\n");
+               exit(EXIT_FAILURE);
+            }
+
             if (opt.thumb)
                opt.thumb_file = name_thumbnail(opt.output_file);
          }
@@ -157,6 +183,27 @@ name_thumbnail(char *name)
    return new_title;
 }
 
+void
+options_parse_autoselect(char *optarg)
+{
+   char *tok;
+   const char tokdelim[2] = ",";
+   int dimensions[4];
+   int i=0;
+
+   if (strchr(optarg, ',')) /* geometry dimensions must be in format x,y,w,h   */
+   {
+     dimensions[i++] = atoi(strtok(optarg, tokdelim));
+     while (tok = strtok(NULL, tokdelim) )
+        dimensions[i++] = atoi(tok);
+     opt.autoselect=1;
+     opt.autoselect_x=dimensions[0];
+     opt.autoselect_y=dimensions[1];
+     opt.autoselect_w=dimensions[2];
+     opt.autoselect_h=dimensions[3];
+   }
+}
+
 void
 options_parse_thumbnail(char *optarg)
 {
@@ -219,6 +266,7 @@ show_usage(void)
            "  current directory.\n" "  See man " PACKAGE " for more details\n"
            "  -h, --help                display this help and exit\n"
            "  -v, --version             output version information and exit\n"
+           "  -a, --autoselect          non-interactively choose a rectangle of x,y,w,h\n"
            "  -b, --border              When selecting a window, grab wm border too\n"
            "  -c, --count               show a countdown before taking the shot\n"
            "  -d, --delay NUM           wait NUM seconds before taking a shot\n"
@@ -229,16 +277,18 @@ show_usage(void)
            "                            low quality means high compression.\n"
            "  -m, --multidisp           For multiple heads, grab shot from each\n"
            "                            and join them together.\n"
-           "  -s, --select              interactively choose a window or rectnagle\n"
+           "  -s, --select              interactively choose a window or rectangle\n"
            "                            with the mouse\n"
+           "  -u, --focused             use the currently focused window\n"
            "  -t, --thumb NUM           generate thumbnail too. NUM is the percentage\n"
            "                            of the original size for the thumbnail to be,\n"
            "                            or the geometry in percent, e.g. 50x60 or 80x20.\n"
+           "  -z, --silent              Prevent beeping\n"		   
            "\n" "  SPECIAL STRINGS\n"
            "  Both the --exec and filename parameters can take format specifiers\n"
            "  that are expanded by " PACKAGE " when encountered.\n"
            "  There are two types of format specifier. Characters preceded by a '%%'\n"
-           "  are interpretted by strftime(2). See man strftime for examples.\n"
+           "  are interpreted by strftime(2). See man strftime for examples.\n"
            "  These options may be used to refer to the current date and time.\n"
            "  The second kind are internal to " PACKAGE
            "  and are prefixed by '$'\n"
